%% Import data
England = readtable("England 1920.csv");
France = readtable("France 1920.csv");
Germany = readtable("Germany 1920.csv");
Italy = readtable("Italy 1920.csv");
Scotland = readtable("Scotland 1920.csv");
Spain = readtable("Spain 1920.csv");


%% Find variables in each game
League = struct('England',England,'France',France,'Germany',Germany,'Italy',Italy,'Scotland',Scotland,'Spain',Spain);

Name = ["England" "France" "Germany" "Italy" "Scotland" "Spain"];
Shots = [];
Shots_T = [];
Corners = [];
Fouls = [];
Yellows = [];
Reds = [];
for i = 1:6
    Shots = [Shots; getfield(League,Name(i)).HS + getfield(League,Name(i)).AS];
    Shots_T = [Shots_T; getfield(League,Name(i)).HST + getfield(League,Name(i)).AST];
    Corners = [Corners; getfield(League,Name(i)).HC + getfield(League,Name(i)).AC];
    Fouls = [Fouls; getfield(League,Name(i)).HF + getfield(League,Name(i)).AF];
    Yellows = [Yellows; getfield(League,Name(i)).HY + getfield(League,Name(i)).AY];
    Reds = [Reds; getfield(League,Name(i)).HR + getfield(League,Name(i)).AR];
end


%% Compare variables among all leagues
Eng = [];
for i = 1:380
    Eng = [Eng "England"];
end

Fra = [];
for i = 1:279
    Fra = [Fra "France"];
end

Ger = [];
for i = 1:306
    Ger = [Ger "Germany"];
end

Ita = [];
for i = 1:380
    Ita = [Ita "Italy"];
end

Sco = [];
for i = 1:179
    Sco = [Sco "Scotland"];
end

Spa = [];
for i = 1:380
    Spa = [Spa "Spain"];
end

Group = [Eng Fra Ger Ita Sco Spa];

[P_shots,~,Stats_shots] = anova1(Shots',Group);
C_shots = multcompare(Stats_shots); %1-2=Groups; 3,5=CI; 4=diff; 6=p-val

[P_shots_T,~,Stats_shots_T] = anova1(Shots_T',Group);
C_shots_T = multcompare(Stats_shots_T);

[P_fouls,~,Stats_fouls] = anova1(Fouls',Group);
C_fouls = multcompare(Stats_fouls);

[P_corners,~,Stats_corners] = anova1(Corners',Group);
C_corners = multcompare(Stats_corners);

[P_yellows,~,Stats_yellows] = anova1(Yellows',Group);
C_yellows = multcompare(Stats_yellows);

[P_reds,~,Stats_reds] = anova1(Reds',Group);
C_reds = multcompare(Stats_reds);


%% Create a table and save
N = ["C_shots" "C_shots_T" "C_corners" "C_fouls" "C_yellows" "C_reds"];
C = struct(N(1),C_shots,N(2),C_shots_T,N(3),C_corners,N(4),C_fouls,N(5),C_yellows,N(6),C_reds);
Name = ["Country 1" "Country 2" "95% CI low" "Difference" "95% CI high", "P-value"];
for i = 1:6
    Table = splitvars(table(getfield(C,N(i))),"Var1",'NewVariableNames',Name);
    writetable(Table,strcat(N(i),".xlsx"));
    Table = [];
end

%% Create excel file
for i = 1:6
    Shots_ex{i} = getfield(League,Name(i)).HS + getfield(League,Name(i)).AS;
    Shots_T_ex{i} = getfield(League,Name(i)).HST + getfield(League,Name(i)).AST;
    Corners_ex{i} = getfield(League,Name(i)).HC + getfield(League,Name(i)).AC;
    Fouls_ex{i} = getfield(League,Name(i)).HF + getfield(League,Name(i)).AF;
    Yellows_ex{i} = getfield(League,Name(i)).HY + getfield(League,Name(i)).AY;
    Reds_ex{i} = getfield(League,Name(i)).HR + getfield(League,Name(i)).AR;
end

Var_name = ["Shots" "Shots on target" "Corner kicks" "Fouls" "Yellow cards", "Red cards"];
Tab_name = ["England.xlsx" "France.xlsx" "Germany.xlsx" "Italy.xlsx" "Scotland.xlsx" "Spain.xlsx"];
for i = 1:6
    Tab = table(Shots_ex{i},Shots_T_ex{i},Corners_ex{i},Fouls_ex{i},Yellows_ex{i},Reds_ex{i},...
        'VariableNames',Var_name);
    writetable(Tab,Tab_name(i));
end






